#ifdef __cplusplus
extern "C" {
#endif

#include "uulib/clear.h"

#ifdef __cplusplus
}
#endif

void uu_clear(struct uu *io) {
  io->time_low              = 0;
  io->time_mid              = 0;
  io->time_high_and_version = 0;
  io->clock_seq_and_variant = 0;
  io->node[0]               = 0;
  io->node[1]               = 0;
  io->node[2]               = 0;
  io->node[3]               = 0;
  io->node[4]               = 0;
  io->node[5]               = 0;
}

/* ex:set ts=2 sw=2 itab=spaces: */
